@@ -4,21 +4,33 @@ package Firewall::Config::Element::Role;
 # 加载扩展模块
 #------------------------------------------------------------------------------
 use Moose::Role;
+use namespace::autoclean;
+
+# no warnings 'uninitialized';
 
 #------------------------------------------------------------------------------
-# Firewall::Config::Element::Role 通用属性
+# 定义 Firewall::Config::Element::Role 方法属性
 #------------------------------------------------------------------------------
-# 防火墙ID
-has fwId => (is => 'ro', isa => 'Int', required => 0,);
+has fwId => (is => 'ro', isa => 'Int|Undef', required => 0,);
 
-# 在同一个设备中描述一个对象的唯一性特征
+#------------------------------------------------------------------------------
+# sign 属性签名算法 | 懒加载，确实需要时加载
+#------------------------------------------------------------------------------
 has sign => (is => 'ro', isa => 'Str', lazy => 1, builder => '_buildSign',);
 
-# 设备的配置内容
-has config => (is => 'ro', isa => 'Str', required => 0,);
+#------------------------------------------------------------------------------
+# config 属性的具体配置
+#------------------------------------------------------------------------------
+has config => (
+  is       => 'ro',
+  isa      => 'ArrayRef',
+  required => 0,
+  traits   => ['Array'],
+  handles  => {addConfig => 'push', insertConfig => 'unshift'}
+);
 
 #------------------------------------------------------------------------------
-# 应用该模块需要具体实现 _buildSign
+# 继续 Firewall::Config::Element::Role 必须实现 _buildSign 方法
 #------------------------------------------------------------------------------
 requires '_buildSign';
 
@@ -28,7 +40,8 @@ requires '_buildSign';
 sub createSign {
   my $self = shift;
 
-  #confess "ERROR: 用于生成 sign 的参数成员不能是 undefined" if grep { not defined } @_;
+  # 边界条件判断
+  # confess "ERROR: 用于生成 sign 的参数成员不能是 undefined" if grep { not defined } @_;
   return (join('<|>', @_));
 }
 
